@@ -22,7 +22,7 @@ from babeldoc.translator.translator import OpenAITranslator
 from babeldoc.translator.translator import set_translate_rate_limiter
 
 logger = logging.getLogger(__name__)
-__version__ = "0.4.15"
+__version__ = "0.4.19"
 
 
 def create_parser():
@@ -67,6 +67,10 @@ def create_parser():
         "--rpc-doclayout3",
         help="RPC service host address for document layout analysis",
     )
+    parser.add_argument(
+        "--rpc-doclayout4",
+        help="RPC service host address for document layout analysis",
+    )
     parser.add_argument(
         "--generate-offline-assets",
         default=None,
@@ -373,6 +377,10 @@ async def main():
         from babeldoc.docvision.rpc_doclayout3 import RpcDocLayoutModel
 
         doc_layout_model = RpcDocLayoutModel(host=args.rpc_doclayout3)
+    elif args.rpc_doclayout4:
+        from babeldoc.docvision.rpc_doclayout4 import RpcDocLayoutModel
+
+        doc_layout_model = RpcDocLayoutModel(host=args.rpc_doclayout4)
     else:
         from babeldoc.docvision.doclayout import DocLayoutModel
 
